/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.marketplace.service.impl;

import com.liferay.marketplace.internal.service.permission.MarketplacePermission;
import com.liferay.marketplace.model.App;
import com.liferay.marketplace.service.base.AppServiceBaseImpl;
import com.liferay.portal.kernel.exception.PortalException;

import java.io.File;

/**
 * @author Ryan Park
 */
public class AppServiceImpl extends AppServiceBaseImpl {

	@Override
	public App deleteApp(long appId) throws PortalException {
		MarketplacePermission.check(getPermissionChecker());

		return appLocalService.deleteApp(appId);
	}

	@Override
	public void installApp(long remoteAppId) throws PortalException {
		MarketplacePermission.check(getPermissionChecker());

		appLocalService.installApp(remoteAppId);
	}

	@Override
	public void uninstallApp(long remoteAppId) throws PortalException {
		MarketplacePermission.check(getPermissionChecker());

		appLocalService.uninstallApp(remoteAppId);
	}

	@Override
	public App updateApp(File file) throws PortalException {
		MarketplacePermission.check(getPermissionChecker());

		return appLocalService.updateApp(getUserId(), file);
	}

}